# Any Dice simulator

      ____                ____             ____
     /\' .\    _____     /\' .\   _____   /\' .\   _____
    /: \___\  / .  /\   /: \___\ / .  /\ /: \___\ / .  /\
    \' / . / /____/..\  \' / . //____/..\\' / . //____/..\ 
     \/___/  \'  '\  /   \/___/ \'  '\  / \/___/ \'  '\  /
              \'__'\/            \'__'\/          \'__'\/

A Python package to roll any dice combo!

### Installation
```
pip3 install Any-Dice-Simulator
```
### Usage
Import the core function using:
```python
from anyDiceSimulator import myfunctions
```

Roll a dice combo:
Example: If you need to roll a 6 sided die 5 times, input 5d6
```python
myfunctions.rolldice('5d6')
```
### Todo [Not exhaustive]
- Add functionality to roll biased die
- Functionality to roll multiple types of die at once
- Try an object oriented approach with the code
- Add external random number generators
- Add dice rolling graphic
